@@ -29,9 +29,6 @@ from werkzeug.http import generate_etag
 from werkzeug.test import Client
 from werkzeug.test import create_environ
 from werkzeug.test import run_wsgi_app
-from werkzeug.wrappers.cors import CORSRequestMixin
-from werkzeug.wrappers.cors import CORSResponseMixin
-from werkzeug.wrappers.json import JSONMixin
 from werkzeug.wsgi import LimitedStream
 from werkzeug.wsgi import wrap_file
 
@@ -446,247 +443,13 @@ def test_etag_request():
     assert request.if_unmodified_since == dt
 
 
-@pytest.mark.parametrize(
-    ("user_agent", "browser", "platform", "version", "language"),
-    (
-        (
-            "Mozilla/5.0 (Macintosh; U; Intel Mac OS X; en-US; rv:1.8.1.11) "
-            "Gecko/20071127 Firefox/2.0.0.11",
-            "firefox",
-            "macos",
-            "2.0.0.11",
-            "en-US",
-        ),
-        (
-            "Mozilla/4.0 (compatible; MSIE 6.0; Windows NT 5.1; de-DE) Opera 8.54",
-            "opera",
-            "windows",
-            "8.54",
-            "de-DE",
-        ),
-        (
-            "Mozilla/5.0 (iPhone; U; CPU like Mac OS X; en) AppleWebKit/420 "
-            "(KHTML, like Gecko) Version/3.0 Mobile/1A543a Safari/419.3",
-            "safari",
-            "iphone",
-            "3.0",
-            "en",
-        ),
-        (
-            "Bot Googlebot/2.1 ( http://www.googlebot.com/bot.html)",
-            "google",
-            None,
-            "2.1",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; CrOS armv7l 3701.81.0) AppleWebKit/537.31 "
-            "(KHTML, like Gecko) Chrome/26.0.1410.57 Safari/537.31",
-            "chrome",
-            "chromeos",
-            "26.0.1410.57",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (Windows NT 6.3; Trident/7.0; .NET4.0E; rv:11.0) like Gecko",
-            "msie",
-            "windows",
-            "11.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (SymbianOS/9.3; Series60/3.2 NokiaE5-00/101.003; "
-            "Profile/MIDP-2.1 Configuration/CLDC-1.1 ) AppleWebKit/533.4 "
-            "(KHTML, like Gecko) NokiaBrowser/7.3.1.35 Mobile Safari/533.4 3gpp-gba",
-            "safari",
-            "symbian",
-            "533.4",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; OpenBSD amd64; rv:45.0) Gecko/20100101 Firefox/45.0",
-            "firefox",
-            "openbsd",
-            "45.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; NetBSD amd64; rv:45.0) Gecko/20100101 Firefox/45.0",
-            "firefox",
-            "netbsd",
-            "45.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; FreeBSD amd64) AppleWebKit/537.36 (KHTML, like Gecko) "
-            "Chrome/48.0.2564.103 Safari/537.36",
-            "chrome",
-            "freebsd",
-            "48.0.2564.103",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; FreeBSD amd64; rv:45.0) Gecko/20100101 Firefox/45.0",
-            "firefox",
-            "freebsd",
-            "45.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; U; NetBSD amd64; en-US; rv:) Gecko/20150921 "
-            "SeaMonkey/1.1.18",
-            "seamonkey",
-            "netbsd",
-            "1.1.18",
-            "en-US",
-        ),
-        (
-            "Mozilla/5.0 (Windows; U; Windows NT 6.2; WOW64; rv:1.8.0.7) "
-            "Gecko/20110321 MultiZilla/4.33.2.6a SeaMonkey/8.6.55",
-            "seamonkey",
-            "windows",
-            "8.6.55",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; Linux x86_64; rv:12.0) Gecko/20120427 Firefox/12.0 "
-            "SeaMonkey/2.9",
-            "seamonkey",
-            "linux",
-            "2.9",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (compatible; Baiduspider/2.0; "
-            "+http://www.baidu.com/search/spider.html)",
-            "baidu",
-            None,
-            "2.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; SunOS i86pc; rv:38.0) Gecko/20100101 Firefox/38.0",
-            "firefox",
-            "solaris",
-            "38.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; Linux x86_64; rv:38.0) Gecko/20100101 Firefox/38.0 "
-            "Iceweasel/38.7.1",
-            "firefox",
-            "linux",
-            "38.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 "
-            "(KHTML, like Gecko) Chrome/50.0.2661.75 Safari/537.36",
-            "chrome",
-            "windows",
-            "50.0.2661.75",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (compatible; bingbot/2.0; +http://www.bing.com/bingbot.htm)",
-            "bing",
-            None,
-            "2.0",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; DragonFly x86_64) AppleWebKit/537.36 "
-            "(KHTML, like Gecko) Chrome/47.0.2526.106 Safari/537.36",
-            "chrome",
-            "dragonflybsd",
-            "47.0.2526.106",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (X11; U; DragonFly i386; de; rv:1.9.1) "
-            "Gecko/20090720 Firefox/3.5.1",
-            "firefox",
-            "dragonflybsd",
-            "3.5.1",
-            "de",
-        ),
-        (
-            "Mozilla/5.0 (Macintosh; Intel Mac OS X 10_13_5) AppleWebKit/537.36"
-            "(KHTML, like Gecko) Chrome/73.0.3683.103 Safari/537.36 OPR/60.0.3255.95",
-            "opera",
-            "macos",
-            "60.0.3255.95",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (Linux; Android 4.4.4; Google Nexus 7 2013 - 4.4.4 - "
-            "API 19 - 1200x1920 Build/KTU84P) AppleWebKit/537.36 (KHTML, like Gecko) "
-            "Chrome/51.0.2704.106 Crosswalk/21.51.546.7 Safari/537.36",
-            "chrome",
-            "android",
-            "51.0.2704.106",
-            None,
-        ),
-        (
-            "Mozilla/5.0 (Linux; Android; motorola edge) AppleWebKit/537.36 "
-            "(KHTML, like Gecko) Chrome/85.0.4183.81 Mobile Safari/537.36",
-            "chrome",
-            "android",
-            "85.0.4183.81",
-            None,
-        ),
-        (
-            "Mozilla/4.0 (compatible; MSIE 7.0; Windows NT 5.1; Trident/4.0; "
-            ".NET CLR 1.1.4322)",
-            "msie",
-            "windows",
-            "7.0",
-            None,
-        ),
-    ),
-)
-def test_user_agent(user_agent, browser, platform, version, language):
+def test_user_agent():
+    user_agent = "Mozilla/5.0 (X11; Linux x86_64; rv:94.0) Gecko/20100101 Firefox/94.0"
     request = wrappers.Request({"HTTP_USER_AGENT": user_agent})
-
     assert request.user_agent.to_header() == user_agent
     assert str(request.user_agent) == user_agent
     assert request.user_agent.string == user_agent
 
-    with pytest.deprecated_call():
-        assert request.user_agent.browser == browser
-
-    with pytest.deprecated_call():
-        assert request.user_agent.platform == platform
-
-    with pytest.deprecated_call():
-        assert request.user_agent.version == version
-
-    with pytest.deprecated_call():
-        assert request.user_agent.language == language
-
-    with pytest.deprecated_call():
-        assert bool(request.user_agent)
-
-    from werkzeug import useragents
-
-    with pytest.deprecated_call():
-        useragents.UserAgent("")
-
-    with pytest.deprecated_call(match="environ"):
-        useragents.UserAgent({})
-
-    with pytest.deprecated_call():
-        useragents.UserAgentParser()
-
-
-def test_invalid_user_agent():
-    request = wrappers.Request(
-        {"HTTP_USER_AGENT": "foo", "SERVER_NAME": "eggs", "SERVER_PORT": "80"}
-    )
-
-    with pytest.deprecated_call():
-        assert not request.user_agent
-
 
 def test_stream_wrapping():
     class LowercasingStream:
@@ -1583,13 +1346,17 @@ class TestJSON:
         )
         assert response.json == value
 
-    def test_force(self):
+    def test_bad_content_type(self):
         value = [1, 2, 3]
         request = wrappers.Request.from_values(json=value, content_type="text/plain")
-        assert request.json is None
+
+        with pytest.raises(BadRequest):
+            request.get_json()
+
+        assert request.get_json(silent=True) is None
         assert request.get_json(force=True) == value
 
-    def test_silent(self):
+    def test_bad_data(self):
         request = wrappers.Request.from_values(
             data=b'{"a":}', content_type="application/json"
         )
@@ -1608,71 +1375,6 @@ class TestJSON:
             request.get_json()
 
 
-@pytest.mark.parametrize(
-    "cls",
-    [
-        wrappers.BaseRequest,
-        wrappers.CommonRequestDescriptorsMixin,
-        wrappers.AcceptMixin,
-        wrappers.ETagRequestMixin,
-        wrappers.UserAgentMixin,
-        wrappers.AuthorizationMixin,
-        wrappers.StreamOnlyMixin,
-        wrappers.PlainRequest,
-        CORSRequestMixin,
-        JSONMixin,
-    ],
-)
-def test_request_mixins_deprecated(cls):
-    class CheckRequest(cls, wrappers.Request):
-        pass
-
-    with pytest.deprecated_call(match=cls.__name__):
-        CheckRequest({"SERVER_NAME": "example.org", "SERVER_PORT": "80"})
-
-
-@pytest.mark.parametrize(
-    "cls",
-    [
-        wrappers.BaseResponse,
-        wrappers.CommonResponseDescriptorsMixin,
-        wrappers.ResponseStreamMixin,
-        wrappers.ETagResponseMixin,
-        wrappers.WWWAuthenticateMixin,
-        CORSResponseMixin,
-        JSONMixin,
-    ],
-)
-def test_response_mixins_deprecated(cls):
-    class CheckResponse(cls, wrappers.Response):
-        pass
-
-    with pytest.deprecated_call(match=cls.__name__):
-        CheckResponse()
-
-
-def test_check_base_deprecated():
-    with pytest.deprecated_call(match=r"issubclass\(cls, Request\)"):
-        assert issubclass(wrappers.Request, wrappers.BaseRequest)
-
-    with pytest.deprecated_call(match=r"isinstance\(obj, Request\)"):
-        assert isinstance(
-            wrappers.Request({"SERVER_NAME": "example.org", "SERVER_PORT": "80"}),
-            wrappers.BaseRequest,
-        )
-
-    with pytest.deprecated_call(match=r"issubclass\(cls, Response\)"):
-        assert issubclass(wrappers.Response, wrappers.BaseResponse)
-
-    with pytest.deprecated_call(match=r"isinstance\(obj, Response\)"):
-        assert isinstance(wrappers.Response(), wrappers.BaseResponse)
-
-
-def test_response_freeze_no_etag_deprecated():
-    with pytest.deprecated_call(match="no_etag"):
-        Response("Hello, World!").freeze(no_etag=True)
-
-
 def test_response_coop():
     response = wrappers.Response("Hello World")
     assert response.cross_origin_opener_policy is COOP.UNSAFE_NONE
